"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import prodvana.proto.prodvana.delivery_module.config_pb2
import prodvana.proto.prodvana.delivery_module.object_pb2
import prodvana.proto.prodvana.version.source_metadata_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ConfigureDeliveryModuleReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELIVERY_MODULE_CONFIG_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    SOURCE_METADATA_FIELD_NUMBER: builtins.int
    @property
    def delivery_module_config(self) -> prodvana.proto.prodvana.delivery_module.config_pb2.DeliveryModuleConfig: ...
    source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType
    @property
    def source_metadata(self) -> prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata: ...
    def __init__(
        self,
        *,
        delivery_module_config: prodvana.proto.prodvana.delivery_module.config_pb2.DeliveryModuleConfig | None = ...,
        source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType = ...,
        source_metadata: prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["delivery_module_config", b"delivery_module_config", "source_metadata", b"source_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_module_config", b"delivery_module_config", "source", b"source", "source_metadata", b"source_metadata"]) -> None: ...

global___ConfigureDeliveryModuleReq = ConfigureDeliveryModuleReq

class ConfigureDeliveryModuleResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELIVERY_MODULE_ID_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    delivery_module_id: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        delivery_module_id: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_module_id", b"delivery_module_id", "version", b"version"]) -> None: ...

global___ConfigureDeliveryModuleResp = ConfigureDeliveryModuleResp

class ValidateConfigureDeliveryModuleResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ValidateConfigureDeliveryModuleResp = ValidateConfigureDeliveryModuleResp

class ListDeliveryModulesReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    page_token: builtins.str
    page_size: builtins.int
    def __init__(
        self,
        *,
        page_token: builtins.str = ...,
        page_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListDeliveryModulesReq = ListDeliveryModulesReq

class ListDeliveryModulesResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELIVERY_MODULES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    @property
    def delivery_modules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.delivery_module.object_pb2.DeliveryModule]: ...
    next_page_token: builtins.str
    def __init__(
        self,
        *,
        delivery_modules: collections.abc.Iterable[prodvana.proto.prodvana.delivery_module.object_pb2.DeliveryModule] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_modules", b"delivery_modules", "next_page_token", b"next_page_token"]) -> None: ...

global___ListDeliveryModulesResp = ListDeliveryModulesResp

class GetDeliveryModuleReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELIVERY_MODULE_FIELD_NUMBER: builtins.int
    delivery_module: builtins.str
    def __init__(
        self,
        *,
        delivery_module: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_module", b"delivery_module"]) -> None: ...

global___GetDeliveryModuleReq = GetDeliveryModuleReq

class GetDeliveryModuleResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELIVERY_MODULE_FIELD_NUMBER: builtins.int
    @property
    def delivery_module(self) -> prodvana.proto.prodvana.delivery_module.object_pb2.DeliveryModule: ...
    def __init__(
        self,
        *,
        delivery_module: prodvana.proto.prodvana.delivery_module.object_pb2.DeliveryModule | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["delivery_module", b"delivery_module"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_module", b"delivery_module"]) -> None: ...

global___GetDeliveryModuleResp = GetDeliveryModuleResp

class GetDeliveryModuleConfigReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELIVERY_MODULE_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    delivery_module: builtins.str
    version: builtins.str
    """omit to get latest version"""
    def __init__(
        self,
        *,
        delivery_module: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_module", b"delivery_module", "version", b"version"]) -> None: ...

global___GetDeliveryModuleConfigReq = GetDeliveryModuleConfigReq

class GetDeliveryModuleConfigResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    @property
    def config(self) -> prodvana.proto.prodvana.delivery_module.config_pb2.DeliveryModuleConfig: ...
    version: builtins.str
    def __init__(
        self,
        *,
        config: prodvana.proto.prodvana.delivery_module.config_pb2.DeliveryModuleConfig | None = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config", "version", b"version"]) -> None: ...

global___GetDeliveryModuleConfigResp = GetDeliveryModuleConfigResp
