# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/pipelines/object.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from prodvana.proto.prodvana.pipelines import pipelines_pb2 as prodvana_dot_pipelines_dot_pipelines__pb2
from prodvana.proto.prodvana.common_config import meta_pb2 as prodvana_dot_common__config_dot_meta__pb2
from prodvana.proto.prodvana.common_config import version_push_pb2 as prodvana_dot_common__config_dot_version__push__pb2
from prodvana.proto.prodvana.object import meta_pb2 as prodvana_dot_object_dot_meta__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fprodvana/pipelines/object.proto\x12\x12prodvana.pipelines\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\"prodvana/pipelines/pipelines.proto\x1a!prodvana/common_config/meta.proto\x1a)prodvana/common_config/version_push.proto\x1a\x1aprodvana/object/meta.proto\"y\n\x10ServicePushParam\x12\x0f\n\x07service\x18\x01 \x01(\t\x12?\n\x0cversion_push\x18\x02 \x01(\x0b\x32).prodvana.common_config.VersionPushOption\x12\x13\n\x0b\x61pplication\x18\x03 \x01(\t\"\xb6\x01\n\x13ServiceInstancePush\x12\x35\n\x10\x61pplication_meta\x18\x01 \x01(\x0b\x32\x1b.prodvana.object.ObjectMeta\x12P\n\x15service_instance_meta\x18\x02 \x01(\x0b\x32\x31.prodvana.common_config.ServiceInstanceObjectMeta\x12\x16\n\x0etarget_version\x18\x03 \x01(\t\"\x9a\x01\n\nTaskStatus\x12\n\n\x02id\x18\x01 \x01(\x05\x12\r\n\x05state\x18\x02 \x01(\t\x12\x36\n\x12\x63reation_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x15last_update_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x0f\n\rPipelineState\"\x9b\x01\n\x08Pipeline\x12)\n\x04meta\x18\x01 \x01(\x0b\x32\x1b.prodvana.object.ObjectMeta\x12\x32\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\".prodvana.pipelines.PipelineConfig\x12\x30\n\x05state\x18\x03 \x01(\x0b\x32!.prodvana.pipelines.PipelineState\"\x9a\x02\n\x11PipelineRunConfig\x12;\n\x0fpipeline_config\x18\x01 \x01(\x0b\x32\".prodvana.pipelines.PipelineConfig\x12\x41\n\x13service_push_params\x18\x02 \x03(\x0b\x32$.prodvana.pipelines.ServicePushParam\x12 \n\x18skip_rollback_validation\x18\x03 \x01(\x08\x12H\n\x17service_instance_pushes\x18\x04 \x03(\x0b\x32\'.prodvana.pipelines.ServiceInstancePush\x12\x19\n\x11skip_alert_checks\x18\x05 \x01(\x08\"\xbb\x02\n\x10PipelineRunState\x12\x36\n\x12\x63reation_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x15last_update_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05state\x18\x03 \x01(\t\x12\x10\n\x08terminal\x18\x04 \x01(\x08\x12\x35\n\rtask_statuses\x18\x05 \x03(\x0b\x32\x1e.prodvana.pipelines.TaskStatus\x12\x11\n\tlastActor\x18\x06 \x01(\t\x12\x11\n\tinitiator\x18\x07 \x01(\t\x12\x0e\n\x06reason\x18\x08 \x01(\t\x12\x0f\n\x07message\x18\t \x01(\t\x12\x15\n\rexternal_link\x18\n \x01(\t\"\xb6\x01\n\x0bPipelineRun\x12;\n\x04meta\x18\x01 \x01(\x0b\x32-.prodvana.common_config.PipelineRunObjectMeta\x12\x35\n\x06\x63onfig\x18\x02 \x01(\x0b\x32%.prodvana.pipelines.PipelineRunConfig\x12\x33\n\x05state\x18\x03 \x01(\x0b\x32$.prodvana.pipelines.PipelineRunStateBNZLgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/pipelinesb\x06proto3')



_SERVICEPUSHPARAM = DESCRIPTOR.message_types_by_name['ServicePushParam']
_SERVICEINSTANCEPUSH = DESCRIPTOR.message_types_by_name['ServiceInstancePush']
_TASKSTATUS = DESCRIPTOR.message_types_by_name['TaskStatus']
_PIPELINESTATE = DESCRIPTOR.message_types_by_name['PipelineState']
_PIPELINE = DESCRIPTOR.message_types_by_name['Pipeline']
_PIPELINERUNCONFIG = DESCRIPTOR.message_types_by_name['PipelineRunConfig']
_PIPELINERUNSTATE = DESCRIPTOR.message_types_by_name['PipelineRunState']
_PIPELINERUN = DESCRIPTOR.message_types_by_name['PipelineRun']
ServicePushParam = _reflection.GeneratedProtocolMessageType('ServicePushParam', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEPUSHPARAM,
  '__module__' : 'prodvana.pipelines.object_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.pipelines.ServicePushParam)
  })
_sym_db.RegisterMessage(ServicePushParam)

ServiceInstancePush = _reflection.GeneratedProtocolMessageType('ServiceInstancePush', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEINSTANCEPUSH,
  '__module__' : 'prodvana.pipelines.object_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.pipelines.ServiceInstancePush)
  })
_sym_db.RegisterMessage(ServiceInstancePush)

TaskStatus = _reflection.GeneratedProtocolMessageType('TaskStatus', (_message.Message,), {
  'DESCRIPTOR' : _TASKSTATUS,
  '__module__' : 'prodvana.pipelines.object_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.pipelines.TaskStatus)
  })
_sym_db.RegisterMessage(TaskStatus)

PipelineState = _reflection.GeneratedProtocolMessageType('PipelineState', (_message.Message,), {
  'DESCRIPTOR' : _PIPELINESTATE,
  '__module__' : 'prodvana.pipelines.object_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.pipelines.PipelineState)
  })
_sym_db.RegisterMessage(PipelineState)

Pipeline = _reflection.GeneratedProtocolMessageType('Pipeline', (_message.Message,), {
  'DESCRIPTOR' : _PIPELINE,
  '__module__' : 'prodvana.pipelines.object_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.pipelines.Pipeline)
  })
_sym_db.RegisterMessage(Pipeline)

PipelineRunConfig = _reflection.GeneratedProtocolMessageType('PipelineRunConfig', (_message.Message,), {
  'DESCRIPTOR' : _PIPELINERUNCONFIG,
  '__module__' : 'prodvana.pipelines.object_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.pipelines.PipelineRunConfig)
  })
_sym_db.RegisterMessage(PipelineRunConfig)

PipelineRunState = _reflection.GeneratedProtocolMessageType('PipelineRunState', (_message.Message,), {
  'DESCRIPTOR' : _PIPELINERUNSTATE,
  '__module__' : 'prodvana.pipelines.object_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.pipelines.PipelineRunState)
  })
_sym_db.RegisterMessage(PipelineRunState)

PipelineRun = _reflection.GeneratedProtocolMessageType('PipelineRun', (_message.Message,), {
  'DESCRIPTOR' : _PIPELINERUN,
  '__module__' : 'prodvana.pipelines.object_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.pipelines.PipelineRun)
  })
_sym_db.RegisterMessage(PipelineRun)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZLgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/pipelines'
  _SERVICEPUSHPARAM._serialized_start=230
  _SERVICEPUSHPARAM._serialized_end=351
  _SERVICEINSTANCEPUSH._serialized_start=354
  _SERVICEINSTANCEPUSH._serialized_end=536
  _TASKSTATUS._serialized_start=539
  _TASKSTATUS._serialized_end=693
  _PIPELINESTATE._serialized_start=695
  _PIPELINESTATE._serialized_end=710
  _PIPELINE._serialized_start=713
  _PIPELINE._serialized_end=868
  _PIPELINERUNCONFIG._serialized_start=871
  _PIPELINERUNCONFIG._serialized_end=1153
  _PIPELINERUNSTATE._serialized_start=1156
  _PIPELINERUNSTATE._serialized_end=1471
  _PIPELINERUN._serialized_start=1474
  _PIPELINERUN._serialized_end=1656
# @@protoc_insertion_point(module_scope)
