"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import prodvana.proto.prodvana.delivery_module.manager_pb2

class DeliveryModuleManagerStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    ConfigureDeliveryModule: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.delivery_module.manager_pb2.ConfigureDeliveryModuleReq,
        prodvana.proto.prodvana.delivery_module.manager_pb2.ConfigureDeliveryModuleResp,
    ]
    ValidateConfigureDeliveryModule: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.delivery_module.manager_pb2.ConfigureDeliveryModuleReq,
        prodvana.proto.prodvana.delivery_module.manager_pb2.ValidateConfigureDeliveryModuleResp,
    ]
    ListDeliveryModules: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.delivery_module.manager_pb2.ListDeliveryModulesReq,
        prodvana.proto.prodvana.delivery_module.manager_pb2.ListDeliveryModulesResp,
    ]
    GetDeliveryModule: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.delivery_module.manager_pb2.GetDeliveryModuleReq,
        prodvana.proto.prodvana.delivery_module.manager_pb2.GetDeliveryModuleResp,
    ]
    GetDeliveryModuleConfig: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.delivery_module.manager_pb2.GetDeliveryModuleConfigReq,
        prodvana.proto.prodvana.delivery_module.manager_pb2.GetDeliveryModuleConfigResp,
    ]

class DeliveryModuleManagerServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def ConfigureDeliveryModule(
        self,
        request: prodvana.proto.prodvana.delivery_module.manager_pb2.ConfigureDeliveryModuleReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.delivery_module.manager_pb2.ConfigureDeliveryModuleResp: ...
    @abc.abstractmethod
    def ValidateConfigureDeliveryModule(
        self,
        request: prodvana.proto.prodvana.delivery_module.manager_pb2.ConfigureDeliveryModuleReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.delivery_module.manager_pb2.ValidateConfigureDeliveryModuleResp: ...
    @abc.abstractmethod
    def ListDeliveryModules(
        self,
        request: prodvana.proto.prodvana.delivery_module.manager_pb2.ListDeliveryModulesReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.delivery_module.manager_pb2.ListDeliveryModulesResp: ...
    @abc.abstractmethod
    def GetDeliveryModule(
        self,
        request: prodvana.proto.prodvana.delivery_module.manager_pb2.GetDeliveryModuleReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.delivery_module.manager_pb2.GetDeliveryModuleResp: ...
    @abc.abstractmethod
    def GetDeliveryModuleConfig(
        self,
        request: prodvana.proto.prodvana.delivery_module.manager_pb2.GetDeliveryModuleConfigReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.delivery_module.manager_pb2.GetDeliveryModuleConfigResp: ...

def add_DeliveryModuleManagerServicer_to_server(servicer: DeliveryModuleManagerServicer, server: grpc.Server) -> None: ...
