# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/release_channel/release_channel_manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from prodvana.proto.prodvana.events import events_pb2 as prodvana_dot_events_dot_events__pb2
from prodvana.proto.prodvana.release_channel import object_pb2 as prodvana_dot_release__channel_dot_object__pb2
from prodvana.proto.prodvana.release_channel import release_channel_config_pb2 as prodvana_dot_release__channel_dot_release__channel__config__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6prodvana/release_channel/release_channel_manager.proto\x12\x18prodvana.release_channel\x1a\x1cgoogle/api/annotations.proto\x1a\x1cprodvana/events/events.proto\x1a%prodvana/release_channel/object.proto\x1a\x35prodvana/release_channel/release_channel_config.proto\x1a\x17validate/validate.proto\"\x8f\x01\n\x1a\x43onfigureReleaseChannelReq\x12G\n\x0frelease_channel\x18\x01 \x01(\x0b\x32..prodvana.release_channel.ReleaseChannelConfig\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12\x14\n\x0c\x63luster_name\x18\x03 \x01(\t\".\n\x1b\x43onfigureReleaseChannelResp\x12\x0f\n\x07version\x18\x01 \x01(\t\"2\n\x17\x44\x65leteReleaseChannelReq\x12\x17\n\x0frelease_channel\x18\x01 \x01(\t\"\x1a\n\x18\x44\x65leteReleaseChannelResp\"-\n\x16ListReleaseChannelsReq\x12\x13\n\x0b\x61pplication\x18\x01 \x01(\t\"]\n\x17ListReleaseChannelsResp\x12\x42\n\x10release_channels\x18\x01 \x03(\x0b\x32(.prodvana.release_channel.ReleaseChannel\"D\n\x14GetReleaseChannelReq\x12\x13\n\x0b\x61pplication\x18\x01 \x01(\t\x12\x17\n\x0frelease_channel\x18\x02 \x01(\t\"Z\n\x15GetReleaseChannelResp\x12\x41\n\x0frelease_channel\x18\x01 \x01(\x0b\x32(.prodvana.release_channel.ReleaseChannel\"\xa4\x01\n\x1aGetReleaseChannelEventsReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12 \n\x0frelease_channel\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\x12\x1f\n\x17order_by_desc_timestamp\x18\x05 \x01(\x08\"^\n\x1bGetReleaseChannelEventsResp\x12&\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x16.prodvana.events.Event\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xe1\x08\n\x15ReleaseChannelManager\x12\xb1\x01\n\x17\x43onfigureReleaseChannel\x12\x34.prodvana.release_channel.ConfigureReleaseChannelReq\x1a\x35.prodvana.release_channel.ConfigureReleaseChannelResp\")\x82\xd3\xe4\x93\x02#\"\x1e/v1/release-channels/configure:\x01*\x12\xb5\x01\n\x13ListReleaseChannels\x12\x30.prodvana.release_channel.ListReleaseChannelsReq\x1a\x31.prodvana.release_channel.ListReleaseChannelsResp\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/v1/applications/{application=*}/release-channels\x12\xb6\x01\n\x14\x44\x65leteReleaseChannel\x12\x31.prodvana.release_channel.DeleteReleaseChannelReq\x1a\x32.prodvana.release_channel.DeleteReleaseChannelResp\"7\x82\xd3\xe4\x93\x02\x31*//v1/release-channels/{release_channel=*}/delete\x12~\n\x15ListReleaseChannelsV2\x12\x30.prodvana.release_channel.ListReleaseChannelsReq\x1a\x31.prodvana.release_channel.ListReleaseChannelsResp\"\x00\x12\xc3\x01\n\x11GetReleaseChannel\x12..prodvana.release_channel.GetReleaseChannelReq\x1a/.prodvana.release_channel.GetReleaseChannelResp\"M\x82\xd3\xe4\x93\x02G\x12\x45/v1/applications/{application=*}/release-channels/{release_channel=*}\x12\xdc\x01\n\x17GetReleaseChannelEvents\x12\x34.prodvana.release_channel.GetReleaseChannelEventsReq\x1a\x35.prodvana.release_channel.GetReleaseChannelEventsResp\"T\x82\xd3\xe4\x93\x02N\x12L/v1/applications/{application=*}/release-channels/{release_channel=*}/eventsBTZRgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/release_channelb\x06proto3')



_CONFIGURERELEASECHANNELREQ = DESCRIPTOR.message_types_by_name['ConfigureReleaseChannelReq']
_CONFIGURERELEASECHANNELRESP = DESCRIPTOR.message_types_by_name['ConfigureReleaseChannelResp']
_DELETERELEASECHANNELREQ = DESCRIPTOR.message_types_by_name['DeleteReleaseChannelReq']
_DELETERELEASECHANNELRESP = DESCRIPTOR.message_types_by_name['DeleteReleaseChannelResp']
_LISTRELEASECHANNELSREQ = DESCRIPTOR.message_types_by_name['ListReleaseChannelsReq']
_LISTRELEASECHANNELSRESP = DESCRIPTOR.message_types_by_name['ListReleaseChannelsResp']
_GETRELEASECHANNELREQ = DESCRIPTOR.message_types_by_name['GetReleaseChannelReq']
_GETRELEASECHANNELRESP = DESCRIPTOR.message_types_by_name['GetReleaseChannelResp']
_GETRELEASECHANNELEVENTSREQ = DESCRIPTOR.message_types_by_name['GetReleaseChannelEventsReq']
_GETRELEASECHANNELEVENTSRESP = DESCRIPTOR.message_types_by_name['GetReleaseChannelEventsResp']
ConfigureReleaseChannelReq = _reflection.GeneratedProtocolMessageType('ConfigureReleaseChannelReq', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGURERELEASECHANNELREQ,
  '__module__' : 'prodvana.release_channel.release_channel_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.release_channel.ConfigureReleaseChannelReq)
  })
_sym_db.RegisterMessage(ConfigureReleaseChannelReq)

ConfigureReleaseChannelResp = _reflection.GeneratedProtocolMessageType('ConfigureReleaseChannelResp', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGURERELEASECHANNELRESP,
  '__module__' : 'prodvana.release_channel.release_channel_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.release_channel.ConfigureReleaseChannelResp)
  })
_sym_db.RegisterMessage(ConfigureReleaseChannelResp)

DeleteReleaseChannelReq = _reflection.GeneratedProtocolMessageType('DeleteReleaseChannelReq', (_message.Message,), {
  'DESCRIPTOR' : _DELETERELEASECHANNELREQ,
  '__module__' : 'prodvana.release_channel.release_channel_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.release_channel.DeleteReleaseChannelReq)
  })
_sym_db.RegisterMessage(DeleteReleaseChannelReq)

DeleteReleaseChannelResp = _reflection.GeneratedProtocolMessageType('DeleteReleaseChannelResp', (_message.Message,), {
  'DESCRIPTOR' : _DELETERELEASECHANNELRESP,
  '__module__' : 'prodvana.release_channel.release_channel_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.release_channel.DeleteReleaseChannelResp)
  })
_sym_db.RegisterMessage(DeleteReleaseChannelResp)

ListReleaseChannelsReq = _reflection.GeneratedProtocolMessageType('ListReleaseChannelsReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTRELEASECHANNELSREQ,
  '__module__' : 'prodvana.release_channel.release_channel_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.release_channel.ListReleaseChannelsReq)
  })
_sym_db.RegisterMessage(ListReleaseChannelsReq)

ListReleaseChannelsResp = _reflection.GeneratedProtocolMessageType('ListReleaseChannelsResp', (_message.Message,), {
  'DESCRIPTOR' : _LISTRELEASECHANNELSRESP,
  '__module__' : 'prodvana.release_channel.release_channel_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.release_channel.ListReleaseChannelsResp)
  })
_sym_db.RegisterMessage(ListReleaseChannelsResp)

GetReleaseChannelReq = _reflection.GeneratedProtocolMessageType('GetReleaseChannelReq', (_message.Message,), {
  'DESCRIPTOR' : _GETRELEASECHANNELREQ,
  '__module__' : 'prodvana.release_channel.release_channel_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.release_channel.GetReleaseChannelReq)
  })
_sym_db.RegisterMessage(GetReleaseChannelReq)

GetReleaseChannelResp = _reflection.GeneratedProtocolMessageType('GetReleaseChannelResp', (_message.Message,), {
  'DESCRIPTOR' : _GETRELEASECHANNELRESP,
  '__module__' : 'prodvana.release_channel.release_channel_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.release_channel.GetReleaseChannelResp)
  })
_sym_db.RegisterMessage(GetReleaseChannelResp)

GetReleaseChannelEventsReq = _reflection.GeneratedProtocolMessageType('GetReleaseChannelEventsReq', (_message.Message,), {
  'DESCRIPTOR' : _GETRELEASECHANNELEVENTSREQ,
  '__module__' : 'prodvana.release_channel.release_channel_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.release_channel.GetReleaseChannelEventsReq)
  })
_sym_db.RegisterMessage(GetReleaseChannelEventsReq)

GetReleaseChannelEventsResp = _reflection.GeneratedProtocolMessageType('GetReleaseChannelEventsResp', (_message.Message,), {
  'DESCRIPTOR' : _GETRELEASECHANNELEVENTSRESP,
  '__module__' : 'prodvana.release_channel.release_channel_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.release_channel.GetReleaseChannelEventsResp)
  })
_sym_db.RegisterMessage(GetReleaseChannelEventsResp)

_RELEASECHANNELMANAGER = DESCRIPTOR.services_by_name['ReleaseChannelManager']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZRgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/release_channel'
  _GETRELEASECHANNELEVENTSREQ.fields_by_name['application']._options = None
  _GETRELEASECHANNELEVENTSREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETRELEASECHANNELEVENTSREQ.fields_by_name['release_channel']._options = None
  _GETRELEASECHANNELEVENTSREQ.fields_by_name['release_channel']._serialized_options = b'\372B\004r\002\020\001'
  _RELEASECHANNELMANAGER.methods_by_name['ConfigureReleaseChannel']._options = None
  _RELEASECHANNELMANAGER.methods_by_name['ConfigureReleaseChannel']._serialized_options = b'\202\323\344\223\002#\"\036/v1/release-channels/configure:\001*'
  _RELEASECHANNELMANAGER.methods_by_name['ListReleaseChannels']._options = None
  _RELEASECHANNELMANAGER.methods_by_name['ListReleaseChannels']._serialized_options = b'\202\323\344\223\0023\0221/v1/applications/{application=*}/release-channels'
  _RELEASECHANNELMANAGER.methods_by_name['DeleteReleaseChannel']._options = None
  _RELEASECHANNELMANAGER.methods_by_name['DeleteReleaseChannel']._serialized_options = b'\202\323\344\223\0021*//v1/release-channels/{release_channel=*}/delete'
  _RELEASECHANNELMANAGER.methods_by_name['GetReleaseChannel']._options = None
  _RELEASECHANNELMANAGER.methods_by_name['GetReleaseChannel']._serialized_options = b'\202\323\344\223\002G\022E/v1/applications/{application=*}/release-channels/{release_channel=*}'
  _RELEASECHANNELMANAGER.methods_by_name['GetReleaseChannelEvents']._options = None
  _RELEASECHANNELMANAGER.methods_by_name['GetReleaseChannelEvents']._serialized_options = b'\202\323\344\223\002N\022L/v1/applications/{application=*}/release-channels/{release_channel=*}/events'
  _CONFIGURERELEASECHANNELREQ._serialized_start=264
  _CONFIGURERELEASECHANNELREQ._serialized_end=407
  _CONFIGURERELEASECHANNELRESP._serialized_start=409
  _CONFIGURERELEASECHANNELRESP._serialized_end=455
  _DELETERELEASECHANNELREQ._serialized_start=457
  _DELETERELEASECHANNELREQ._serialized_end=507
  _DELETERELEASECHANNELRESP._serialized_start=509
  _DELETERELEASECHANNELRESP._serialized_end=535
  _LISTRELEASECHANNELSREQ._serialized_start=537
  _LISTRELEASECHANNELSREQ._serialized_end=582
  _LISTRELEASECHANNELSRESP._serialized_start=584
  _LISTRELEASECHANNELSRESP._serialized_end=677
  _GETRELEASECHANNELREQ._serialized_start=679
  _GETRELEASECHANNELREQ._serialized_end=747
  _GETRELEASECHANNELRESP._serialized_start=749
  _GETRELEASECHANNELRESP._serialized_end=839
  _GETRELEASECHANNELEVENTSREQ._serialized_start=842
  _GETRELEASECHANNELEVENTSREQ._serialized_end=1006
  _GETRELEASECHANNELEVENTSRESP._serialized_start=1008
  _GETRELEASECHANNELEVENTSRESP._serialized_end=1102
  _RELEASECHANNELMANAGER._serialized_start=1105
  _RELEASECHANNELMANAGER._serialized_end=2226
# @@protoc_insertion_point(module_scope)
