# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/delivery_module/object.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.object import meta_pb2 as prodvana_dot_object_dot_meta__pb2
from prodvana.proto.prodvana.delivery_module import config_pb2 as prodvana_dot_delivery__module_dot_config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%prodvana/delivery_module/object.proto\x12\x18prodvana.delivery_module\x1a\x1aprodvana/object/meta.proto\x1a%prodvana/delivery_module/config.proto\"\xb9\x01\n\x0e\x44\x65liveryModule\x12)\n\x04meta\x18\x01 \x01(\x0b\x32\x1b.prodvana.object.ObjectMeta\x12>\n\x06\x63onfig\x18\x02 \x01(\x0b\x32..prodvana.delivery_module.DeliveryModuleConfig\x12<\n\x05state\x18\x03 \x01(\x0b\x32-.prodvana.delivery_module.DeliveryModuleState\"\x15\n\x13\x44\x65liveryModuleStateBTZRgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/delivery_moduleb\x06proto3')



_DELIVERYMODULE = DESCRIPTOR.message_types_by_name['DeliveryModule']
_DELIVERYMODULESTATE = DESCRIPTOR.message_types_by_name['DeliveryModuleState']
DeliveryModule = _reflection.GeneratedProtocolMessageType('DeliveryModule', (_message.Message,), {
  'DESCRIPTOR' : _DELIVERYMODULE,
  '__module__' : 'prodvana.delivery_module.object_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.delivery_module.DeliveryModule)
  })
_sym_db.RegisterMessage(DeliveryModule)

DeliveryModuleState = _reflection.GeneratedProtocolMessageType('DeliveryModuleState', (_message.Message,), {
  'DESCRIPTOR' : _DELIVERYMODULESTATE,
  '__module__' : 'prodvana.delivery_module.object_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.delivery_module.DeliveryModuleState)
  })
_sym_db.RegisterMessage(DeliveryModuleState)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZRgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/delivery_module'
  _DELIVERYMODULE._serialized_start=135
  _DELIVERYMODULE._serialized_end=320
  _DELIVERYMODULESTATE._serialized_start=322
  _DELIVERYMODULESTATE._serialized_end=343
# @@protoc_insertion_point(module_scope)
