# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/common_config/task.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2
from prodvana.proto.prodvana.common_config import retry_pb2 as prodvana_dot_common__config_dot_retry__pb2
from prodvana.proto.prodvana.common_config import program_pb2 as prodvana_dot_common__config_dot_program__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!prodvana/common_config/task.proto\x12\x16prodvana.common_config\x1a\x17validate/validate.proto\x1a\"prodvana/common_config/retry.proto\x1a$prodvana/common_config/program.proto\"\x89\x01\n\nTaskConfig\x12@\n\x07program\x18\x01 \x01(\x0b\x32%.prodvana.common_config.ProgramConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x39\n\x0cretry_config\x18\x02 \x01(\x0b\x32#.prodvana.common_config.RetryConfigBRZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_configb\x06proto3')



_TASKCONFIG = DESCRIPTOR.message_types_by_name['TaskConfig']
TaskConfig = _reflection.GeneratedProtocolMessageType('TaskConfig', (_message.Message,), {
  'DESCRIPTOR' : _TASKCONFIG,
  '__module__' : 'prodvana.common_config.task_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.common_config.TaskConfig)
  })
_sym_db.RegisterMessage(TaskConfig)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_config'
  _TASKCONFIG.fields_by_name['program']._options = None
  _TASKCONFIG.fields_by_name['program']._serialized_options = b'\372B\005\212\001\002\020\001'
  _TASKCONFIG._serialized_start=161
  _TASKCONFIG._serialized_end=298
# @@protoc_insertion_point(module_scope)
