# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from prodvana.proto.prodvana.delivery_module import manager_pb2 as prodvana_dot_delivery__module_dot_manager__pb2


class DeliveryModuleManagerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ConfigureDeliveryModule = channel.unary_unary(
                '/prodvana.delivery_module.DeliveryModuleManager/ConfigureDeliveryModule',
                request_serializer=prodvana_dot_delivery__module_dot_manager__pb2.ConfigureDeliveryModuleReq.SerializeToString,
                response_deserializer=prodvana_dot_delivery__module_dot_manager__pb2.ConfigureDeliveryModuleResp.FromString,
                )
        self.ValidateConfigureDeliveryModule = channel.unary_unary(
                '/prodvana.delivery_module.DeliveryModuleManager/ValidateConfigureDeliveryModule',
                request_serializer=prodvana_dot_delivery__module_dot_manager__pb2.ConfigureDeliveryModuleReq.SerializeToString,
                response_deserializer=prodvana_dot_delivery__module_dot_manager__pb2.ValidateConfigureDeliveryModuleResp.FromString,
                )
        self.ListDeliveryModules = channel.unary_unary(
                '/prodvana.delivery_module.DeliveryModuleManager/ListDeliveryModules',
                request_serializer=prodvana_dot_delivery__module_dot_manager__pb2.ListDeliveryModulesReq.SerializeToString,
                response_deserializer=prodvana_dot_delivery__module_dot_manager__pb2.ListDeliveryModulesResp.FromString,
                )
        self.GetDeliveryModule = channel.unary_unary(
                '/prodvana.delivery_module.DeliveryModuleManager/GetDeliveryModule',
                request_serializer=prodvana_dot_delivery__module_dot_manager__pb2.GetDeliveryModuleReq.SerializeToString,
                response_deserializer=prodvana_dot_delivery__module_dot_manager__pb2.GetDeliveryModuleResp.FromString,
                )
        self.GetDeliveryModuleConfig = channel.unary_unary(
                '/prodvana.delivery_module.DeliveryModuleManager/GetDeliveryModuleConfig',
                request_serializer=prodvana_dot_delivery__module_dot_manager__pb2.GetDeliveryModuleConfigReq.SerializeToString,
                response_deserializer=prodvana_dot_delivery__module_dot_manager__pb2.GetDeliveryModuleConfigResp.FromString,
                )


class DeliveryModuleManagerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ConfigureDeliveryModule(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateConfigureDeliveryModule(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDeliveryModules(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeliveryModule(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeliveryModuleConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DeliveryModuleManagerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ConfigureDeliveryModule': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureDeliveryModule,
                    request_deserializer=prodvana_dot_delivery__module_dot_manager__pb2.ConfigureDeliveryModuleReq.FromString,
                    response_serializer=prodvana_dot_delivery__module_dot_manager__pb2.ConfigureDeliveryModuleResp.SerializeToString,
            ),
            'ValidateConfigureDeliveryModule': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateConfigureDeliveryModule,
                    request_deserializer=prodvana_dot_delivery__module_dot_manager__pb2.ConfigureDeliveryModuleReq.FromString,
                    response_serializer=prodvana_dot_delivery__module_dot_manager__pb2.ValidateConfigureDeliveryModuleResp.SerializeToString,
            ),
            'ListDeliveryModules': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDeliveryModules,
                    request_deserializer=prodvana_dot_delivery__module_dot_manager__pb2.ListDeliveryModulesReq.FromString,
                    response_serializer=prodvana_dot_delivery__module_dot_manager__pb2.ListDeliveryModulesResp.SerializeToString,
            ),
            'GetDeliveryModule': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDeliveryModule,
                    request_deserializer=prodvana_dot_delivery__module_dot_manager__pb2.GetDeliveryModuleReq.FromString,
                    response_serializer=prodvana_dot_delivery__module_dot_manager__pb2.GetDeliveryModuleResp.SerializeToString,
            ),
            'GetDeliveryModuleConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDeliveryModuleConfig,
                    request_deserializer=prodvana_dot_delivery__module_dot_manager__pb2.GetDeliveryModuleConfigReq.FromString,
                    response_serializer=prodvana_dot_delivery__module_dot_manager__pb2.GetDeliveryModuleConfigResp.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'prodvana.delivery_module.DeliveryModuleManager', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DeliveryModuleManager(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ConfigureDeliveryModule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.delivery_module.DeliveryModuleManager/ConfigureDeliveryModule',
            prodvana_dot_delivery__module_dot_manager__pb2.ConfigureDeliveryModuleReq.SerializeToString,
            prodvana_dot_delivery__module_dot_manager__pb2.ConfigureDeliveryModuleResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidateConfigureDeliveryModule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.delivery_module.DeliveryModuleManager/ValidateConfigureDeliveryModule',
            prodvana_dot_delivery__module_dot_manager__pb2.ConfigureDeliveryModuleReq.SerializeToString,
            prodvana_dot_delivery__module_dot_manager__pb2.ValidateConfigureDeliveryModuleResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDeliveryModules(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.delivery_module.DeliveryModuleManager/ListDeliveryModules',
            prodvana_dot_delivery__module_dot_manager__pb2.ListDeliveryModulesReq.SerializeToString,
            prodvana_dot_delivery__module_dot_manager__pb2.ListDeliveryModulesResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDeliveryModule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.delivery_module.DeliveryModuleManager/GetDeliveryModule',
            prodvana_dot_delivery__module_dot_manager__pb2.GetDeliveryModuleReq.SerializeToString,
            prodvana_dot_delivery__module_dot_manager__pb2.GetDeliveryModuleResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDeliveryModuleConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.delivery_module.DeliveryModuleManager/GetDeliveryModuleConfig',
            prodvana_dot_delivery__module_dot_manager__pb2.GetDeliveryModuleConfigReq.SerializeToString,
            prodvana_dot_delivery__module_dot_manager__pb2.GetDeliveryModuleConfigResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
